==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/admin/triggercreation.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: triggercreation.php,v 1.4 2005/06/22 19:18:05 yeupou Exp $
#
#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";
require ($GLOBALS['sys_www_topdir'].'/include/proj_email.php');

# Skip admin rights check if we are dealing with the sys group
if ($GLOBALS['sys_group_id'] != $group_id)
{ session_require(array('group'=>'1','admin_flags'=>'A')); }

# Configure the project according to group type settings:
#   if a project can use a feature for its group type, assume he would
#   use it by default
$group_type = db_result(db_query("SELECT type FROM groups WHERE group_id=$group_id"),0,'type');
$res_type = db_query("SELECT * FROM group_type WHERE type_id=$group_type");

$to_update = array("homepage", "download", "cvs", "forum","mailing_list","patch","task","news","support","bug");
unset($upd_list);
while (list(,$field) = each($to_update))
{
  # bug = bugs, mailing_list = mail
  $value = db_result($res_type, 0, 'can_use_'.$field);
  
  if ($field == 'mailing_list')
      { $field = 'mail'; }
  if ($field == 'bug')
      { $field = 'bugs'; }
  $field = 'use_'.$field;

  fb(sprintf(_("%s will be set to %s"),$field, $value));
  $upd_list .= "$field='$value',";
}

if ($upd_list)
{
  # strip the excess comma at the end of the update field list
  $upd_list = substr($upd_list,0,-1);
  
  $sql="UPDATE groups SET $upd_list ".
     " WHERE group_id='$group_id'";
  $result=db_affected_rows(db_query($sql));

  if (!$result)
    { 
      fb(_("No field to update or SQL error"));

    }
  else
    { 
      fb_dbsuccess();  
      group_add_history('Set Active Features to the default for the Group Type',user_getname($user_id),$group_id);
    }
}

# Send email and do site specific triggered stuff that comes along
send_new_project_email($group_id);
fb(_("Mail sent, site-specific triggers executed"));

if ($GLOBALS['sys_group_id'] != $group_id)
{ 
  site_admin_header(array('title'=>"Project Creation Trigger"));
  site_admin_footer(array());
}
else
{
  site_header(array('title'=>_("Local Administration Project Approved")));
  site_footer(array());
}
?>

==> savane-1.0.8+2.tar.gz: savane-1.0.8+2/frontend/php/admin/triggercreation.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: triggercreation.php,v 1.5 2005/06/30 17:19:33 toddy Exp $
#
#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


require "../include/pre.php";
require ($GLOBALS['sys_www_topdir'].'/include/proj_email.php');

# Skip admin rights check if we are dealing with the sys group
if ($GLOBALS['sys_group_id'] != $group_id)
{ session_require(array('group'=>'1','admin_flags'=>'A')); }

# Configure the project according to group type settings:
#   if a project can use a feature for its group type, assume he would
#   use it by default
$group_type = db_result(db_query("SELECT type FROM groups WHERE group_id=$group_id"),0,'type');
$res_type = db_query("SELECT * FROM group_type WHERE type_id=$group_type");

$to_update = array("homepage", "download", "cvs", "forum","mailing_list","patch","task","news","support","bug");
unset($upd_list);
while (list(,$field) = each($to_update))
{
  # bug = bugs, mailing_list = mail
  $value = db_result($res_type, 0, 'can_use_'.$field);
  
  if ($field == 'mailing_list')
      { $field = 'mail'; }
  if ($field == 'bug')
      { $field = 'bugs'; }
  $field = 'use_'.$field;

  fb(sprintf(_("%s will be set to %s"),$field, $value));
  $upd_list .= "$field='$value',";
}

if ($upd_list)
{
  # strip the excess comma at the end of the update field list
  $upd_list = substr($upd_list,0,-1);
  
  $sql="UPDATE groups SET $upd_list ".
     " WHERE group_id='$group_id'";
  $result=db_affected_rows(db_query($sql));

  if (!$result)
    { 
      fb(_("No field to update or SQL error"));

    }
  else
    { 
      fb_dbsuccess();  
      group_add_history('Set Active Features to the default for the Group Type',user_getname($user_id),$group_id);
    }
}

# Send email and do site specific triggered stuff that comes along
send_new_project_email($group_id);
fb(_("Mail sent, site-specific triggers executed"));

if ($GLOBALS['sys_group_id'] != $group_id)
{ 
  site_admin_header(array('title'=>"Project Creation Trigger"));
  site_admin_footer(array());
}
else
{
  site_header(array('title'=>_("Local Administration Project Approved")));
  site_footer(array());
}
?>
